parse_flash_event_hypersync

Function parse_flash_event_hypersync 

pub fn parse_flash_event_hypersync(
    dex: SharedDex,
    log: &HypersyncLog,
) -> Result<FlashEvent>
Parses a flash event from a Uniswap V3 log.

Errors

Returns an error if the log parsing fails or if the event data is invalid.

Panics

Panics if the contract address is not set in the log.